==> sadad_payment_flutter-0.0.33.tar.gz: lib/services/appservices.dart <==
import 'dart:convert';
import 'dart:developer';

import 'package:http/http.dart' as http;
import 'package:sadad_payment_flutter/model/creditcardsettingsmodel.dart';

class Baseurl {
  static const baseUrl = "";
}

class ApiEndPoint {
  static const primaryColor = "";
  static const live_CreditCardSettings =
      "https://mapi.sadadqa.com/sdk-api/settings?filter[where][or][0][key]=ENABLE_CREDIT_CARD&filter[where][or][1][key]=ENABLE_DEBIT_CARD&filter[where][or][2][key]=credit_card_bankpage_type&filter[where][or][3][key]=is_apple_pay_payment&filter[where][or][4][key]=is_google_pay_payment&filter[where][or][5][key]=is_american_express&filter[where][or][6][key]=is_cybersourse_visa&filter[where][or][7][key]=is_cybersourse_mastercard";
  static const test_CreditCardSettings =
      "http://176.58.99.102:3003/sdk-api/settings?filter[where][or][0][key]=ENABLE_CREDIT_CARD&filter[where][or][1][key]=ENABLE_DEBIT_CARD&filter[where][or][2][key]=credit_card_bankpage_type&filter[where][or][3][key]=is_apple_pay_payment&filter[where][or][4][key]=is_google_pay_payment&filter[where][or][5][key]=is_american_express&filter[where][or][6][key]=is_cybersourse_visa&filter[where][or][7][key]=is_cybersourse_mastercard";
}

class AppServices {
  static Future<void> getAccessToken() async {
    final url = Uri.parse(
      'https://sadad.de/sadadSDKTestConfig/index.php',
    );
    Map<String, String> header = {'Content-Type': 'application/json'};
    var result = await http.post(
      url,
      headers: header,
    );

    if (result.statusCode == 200) {
      var token = '${jsonDecode(result.body)}';
      print('notification count:::${token}');
    }
  }

  // let request = NSMutableURLRequest(url: NSURL(string: "\(Constant.creditcard_Settings)")! as URL)
  // request.httpMethod = "GET"
  //
  // request.setValue("application/json", forHTTPHeaderField: "Content-Type")
  // request.setValue("\(strAccessToken)", forHTTPHeaderField: "Authorization")

  static Future<List<CreditCardSettingsModel>> getCreditCardSetting({required String token}) async {
    final url = Uri.parse(
      ApiEndPoint.test_CreditCardSettings,
    );
    Map<String, String> header = {'Content-Type': 'application/json', "Authorization": token};
    var result = await http.get(
      url,
      headers: header,
    );
    List<CreditCardSettingsModel> creditCardSettings = [];
    if (result.statusCode == 200) {
      List response = jsonDecode(result.body);
      creditCardSettings = response.map((e) => CreditCardSettingsModel.fromJson(e)).toList();
      log('notification count:::${response}');
    }
    return creditCardSettings;
  }
}

==> sadad_payment_flutter-0.0.34.tar.gz: lib/services/appservices.dart <==
import 'dart:convert';
import 'dart:developer';

import 'package:http/http.dart' as http;
import 'package:sadad_payment_flutter/model/creditcardsettingsmodel.dart';

class Baseurl {
  static const baseUrl = "";
}

class ApiEndPoint {
  static const primaryColor = "";
  static const live_CreditCardSettings =
      "https://mapi.sadadqa.com/sdk-api/settings?filter[where][or][0][key]=ENABLE_CREDIT_CARD&filter[where][or][1][key]=ENABLE_DEBIT_CARD&filter[where][or][2][key]=credit_card_bankpage_type&filter[where][or][3][key]=is_apple_pay_payment&filter[where][or][4][key]=is_google_pay_payment&filter[where][or][5][key]=is_american_express&filter[where][or][6][key]=is_cybersourse_visa&filter[where][or][7][key]=is_cybersourse_mastercard";
  static const test_CreditCardSettings =
      "http://176.58.99.102:3003/sdk-api/settings?filter[where][or][0][key]=ENABLE_CREDIT_CARD&filter[where][or][1][key]=ENABLE_DEBIT_CARD&filter[where][or][2][key]=credit_card_bankpage_type&filter[where][or][3][key]=is_apple_pay_payment&filter[where][or][4][key]=is_google_pay_payment&filter[where][or][5][key]=is_american_express&filter[where][or][6][key]=is_cybersourse_visa&filter[where][or][7][key]=is_cybersourse_mastercard";
}

class AppServices {
  static Future<void> getAccessToken() async {
    final url = Uri.parse(
      'https://sadad.de/sadadSDKTestConfig/index.php',
    );
    Map<String, String> header = {'Content-Type': 'application/json'};
    var result = await http.post(
      url,
      headers: header,
    );

    if (result.statusCode == 200) {
      var token = '${jsonDecode(result.body)}';
      print('notification count:::${token}');
    }
  }

  // let request = NSMutableURLRequest(url: NSURL(string: "\(Constant.creditcard_Settings)")! as URL)
  // request.httpMethod = "GET"
  //
  // request.setValue("application/json", forHTTPHeaderField: "Content-Type")
  // request.setValue("\(strAccessToken)", forHTTPHeaderField: "Authorization")

  static Future<List<CreditCardSettingsModel>> getCreditCardSetting({required String token}) async {
    final url = Uri.parse(
      ApiEndPoint.test_CreditCardSettings,
    );
    Map<String, String> header = {'Content-Type': 'application/json', "Authorization": token};
    var result = await http.get(
      url,
      headers: header,
    );
    List<CreditCardSettingsModel> creditCardSettings = [];
    if (result.statusCode == 200) {
      List response = jsonDecode(result.body);
      creditCardSettings = response.map((e) => CreditCardSettingsModel.fromJson(e)).toList();
      print('notification count:::${response}');
    }
    return creditCardSettings;
  }
}
